@@ -3,6 +3,7 @@ Caching outputs of task/workflow calls (incl. file URI downloader tasks) based o
 inputs. When cached outputs are found for reuse, opens advisory locks (flocks) on any local files
 referenced therein, and updates their access timestamps (atime).
 """
+import abc
 import hashlib
 import json
 import itertools
@@ -16,6 +17,7 @@ from fnmatch import fnmatchcase
 from threading import Lock
 
 from . import config
+from .error import CacheOutputFileAgeError
 
 from .. import Env, Value, Type, Document, Tree, Error
 from .._util import (
@@ -72,30 +74,46 @@ class CallCache(AbstractContextManager):
         return hashlib.sha256(task_string.encode("utf-8")).hexdigest()
 
     def get(
-        self, key: str, output_types: Env.Bindings[Type.Base],
+        self, key: str, output_types: Env.Bindings[Type.Base], inputs: Env.Bindings[Value.Base]
     ) -> Optional[Env.Bindings[Value.Base]]:
         """
-        Resolve cache key to call outputs, if available, or None. When matching outputs are found,
-        opens shared flocks on all files referenced therein, which will remain for the life of the
-        CallCache object.
+        Resolve cache key to call outputs, if available, or None. When matching outputs are found, check to ensure the
+        modification time on any output or input files is older than the modification time for the cache file.
+        Opens shared flocks on all files referenced therein, which will remain for the life of the CallCache object.
         """
         from .. import values_from_json
 
         file_path = os.path.join(self.call_cache_dir, f"{key}.json")
+        file_coherence_checker = FileCoherence(self._logger)
+
         if not self._cfg["call_cache"].get_bool("get"):
             return None
 
+        cache = None
         try:
             with open(file_path, "rb") as file_reader:
-                contents = file_reader.read()
+                cache = values_from_json(json.loads(file_reader.read()), output_types)  # pyre-fixme
         except FileNotFoundError:
             self._logger.info(_("call cache miss", cache_path=file_path))
-            return None
-        contents = json.loads(contents)
-        self._logger.notice(_("call cache hit", cache_path=file_path))  # pyre-fixme
-        return values_from_json(contents, output_types)  # pyre-fixme
+        except Exception as exn:
+            self._logger.warning(
+                _("call cache entry present, but unreadable", cache_path=file_path, error=str(exn))
+            )
+        if cache:
+            self._logger.notice(_("call cache hit", cache_path=file_path))  # pyre-fixme
+            file_list = []
+            # check output and input files
 
-    def put(self, task_key: str, input_digest: str, outputs: Env.Bindings[Value.Base],) -> None:
+            def get_files(file):
+                file_list.append(file)
+
+            Value.rewrite_env_files(cache, get_files)
+            Value.rewrite_env_files(inputs, get_files)
+            if file_coherence_checker.check_files(file_path, file_list):
+                return cache
+        return None
+
+    def put(self, task_key: str, input_digest: str, outputs: Env.Bindings[Value.Base]) -> None:
         """
         Store call outputs for future reuse
         """
@@ -109,8 +127,7 @@ class CallCache(AbstractContextManager):
             Path(filepath).mkdir(parents=True, exist_ok=True)
 
             write_atomic(
-                json.dumps(values_to_json(outputs, namespace=""), indent=2),  # pyre-ignore
-                filename,
+                json.dumps(values_to_json(outputs, namespace=""), indent=2), filename  # pyre-ignore
             )
             self._logger.info(_("call cache insert", cache_path=filename))
 
@@ -184,9 +201,7 @@ class CallCache(AbstractContextManager):
             )
             return None
 
-    def put_download(
-        self, uri: str, filename: str, logger: Optional[logging.Logger] = None,
-    ) -> str:
+    def put_download(self, uri: str, filename: str, logger: Optional[logging.Logger] = None) -> str:
         """
         Move the downloaded file to the cache location & return the new path; or if the uri isn't
         cacheable, return the given path.
@@ -325,3 +340,57 @@ def _excerpt(
             clean(pos.end_line, 1, pos.end_column),
         )
     )
+
+
+class FileCoherence(abc.ABC):
+    """
+    Class to check for file coherence when utilizing an output caching system (based on last modification time
+    for cache and referenced files) for files stored locally.
+    """
+
+    _logger: logging.Logger
+
+    def __init__(self, logger):
+        self._logger = logger
+        self.cache_file_modification_time = 0.0
+
+    def check_files(self, cache_file_path: str, files: list) -> bool:
+        if self.cache_file_modification_time == 0.0:
+            self.cache_file_modification_time = self.get_last_modified_time(cache_file_path)
+        for file_path in files:
+            try:
+                self.check_cache_younger_than_file(output_file_path=file_path)
+            except (FileNotFoundError, CacheOutputFileAgeError):
+                self._logger.warning(
+                    _(
+                        "cache entry invalid due to deleted or modified file",
+                        cache_path=file_path,
+                        file_changed=file_path,
+                    )
+                )
+                try:
+                    os.remove(cache_file_path)
+                except Exception as exn:
+                    self._logger.warning(
+                        _(
+                            "unable to delete invalidated cache entry",
+                            cache_path=file_path,
+                            error=str(exn),
+                        )
+                    )
+                return False
+        return True
+
+    def get_last_modified_time(self, file_path: str) -> float:
+        # returned as seconds since epoch
+        file_modification_time = os.path.getmtime(file_path)
+        sym_link_modification_time = os.lstat(file_path).st_mtime
+
+        return max(file_modification_time, sym_link_modification_time)
+
+    def check_cache_younger_than_file(self, output_file_path: str) -> bool:
+        output_file_modification_time = self.get_last_modified_time(output_file_path)
+        if self.cache_file_modification_time >= output_file_modification_time:
+            return True
+        else:
+            raise CacheOutputFileAgeError
