@@ -305,6 +305,9 @@ class TestEval(unittest.TestCase):
             ("'~~${pi}~'", '"~~3.14159~"', env, "1.0"),
             ("'$~{pi}~~'", '"$3.14159~~"', env, "1.0"),
             ("'$~${pi}~~'", '"$~3.14159~~"', env, "1.0"),
+            ("'~{if f then '~{pi}' else '~{e}'}'", '"2.71828"', env, "1.0"),
+            ("""'~{if f then "~{pi}" else "~{e}"}'""", '"2.71828"', env, "1.0"),
+            (""" "~{if f then "~{pi}" else "~{e}"}" """, '"2.71828"', env, "1.0"),
         )
 
     def test_pair(self):
