@@ -504,6 +504,8 @@ class TestTypes(unittest.TestCase):
         }
         """)
         doc.typecheck()
+        for outp in doc.workflow.outputs:
+            self.assertIsNone(outp.expr.literal)
 
         with self.assertRaises(WDL.Error.ValidationError):
             doc = WDL.parse_document("""
@@ -2203,6 +2205,8 @@ class TestStruct(unittest.TestCase):
         """
         doc = WDL.parse_document(doc)
         doc.typecheck()
+        self.assertIsInstance(doc.workflow.body[0].expr.literal, WDL.Value.Struct)
+        self.assertIsNone(doc.tasks[0].outputs[0].expr.literal)
 
         # quickly check task pickle-ability with struct types
         pickled_task = pickle.dumps(doc.tasks[0])
